@@ -8,6 +8,11 @@ from geopy.geocoders import Nominatim
 from datetime import timedelta
 
 
+
+json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday))
+json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday))
+
+
 def earthquake_distance(place):    
 
 
@@ -33,9 +38,9 @@ def earthquake_distance(place):
     today = datetime.datetime.today()
     yesterday = today - timedelta(days=1)
 
-    url = 'https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday)
+    
 
-    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime=2022-05-23&endtime=2022-05-25')
+    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday))
     data = json.loads(json_url.read())
 
     json_dict = data.get('features')
@@ -78,7 +83,7 @@ def earthquake_distance(place):
     min_value = column.min()
     
     all = df.loc[df['distance'] == min_value]
-    print(all)
+    
     
     
     
@@ -119,9 +124,9 @@ def earthquake_longitude(place):
     today = datetime.datetime.today()
     yesterday = today - timedelta(days=1)
 
-    url = 'https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday)
 
-    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime=2022-05-23&endtime=2022-05-25')
+
+    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday))
     data = json.loads(json_url.read())
 
     json_dict = data.get('features')
@@ -164,7 +169,7 @@ def earthquake_longitude(place):
     min_value = column.min()
     
     all = df.loc[df['distance'] == min_value]
-    print(all)
+    
     
     
     
@@ -205,9 +210,9 @@ def earthquake_latitude(place):
     today = datetime.datetime.today()
     yesterday = today - timedelta(days=1)
 
-    url = 'https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday)
+    
 
-    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime=2022-05-23&endtime=2022-05-25')
+    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday))
     data = json.loads(json_url.read())
 
     json_dict = data.get('features')
@@ -250,7 +255,7 @@ def earthquake_latitude(place):
     min_value = column.min()
     
     all = df.loc[df['distance'] == min_value]
-    print(all)
+    
     
     
     
@@ -291,9 +296,9 @@ def earthquake_magnitude(place):
     today = datetime.datetime.today()
     yesterday = today - timedelta(days=1)
 
-    url = 'https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday)
+    
 
-    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime=2022-05-23&endtime=2022-05-25')
+    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday))
     data = json.loads(json_url.read())
 
     json_dict = data.get('features')
@@ -336,7 +341,7 @@ def earthquake_magnitude(place):
     min_value = column.min()
     
     all = df.loc[df['distance'] == min_value]
-    print(all)
+    
     
     
     
@@ -376,9 +381,9 @@ def earthquake_place(place):
     today = datetime.datetime.today()
     yesterday = today - timedelta(days=1)
 
-    url = 'https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday)
+    
 
-    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime=2022-05-23&endtime=2022-05-25')
+    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday))
     data = json.loads(json_url.read())
 
     json_dict = data.get('features')
@@ -421,7 +426,7 @@ def earthquake_place(place):
     min_value = column.min()
     
     all = df.loc[df['distance'] == min_value]
-    print(all)
+    
     
     
     
@@ -462,9 +467,9 @@ def earthquake_time(place):
     today = datetime.datetime.today()
     yesterday = today - timedelta(days=1)
 
-    url = 'https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday)
+    
 
-    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime=2022-05-23&endtime=2022-05-25')
+    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday))
     data = json.loads(json_url.read())
 
     json_dict = data.get('features')
@@ -507,7 +512,7 @@ def earthquake_time(place):
     min_value = column.min()
     
     all = df.loc[df['distance'] == min_value]
-    print(all)
+    
     
     
     
@@ -546,9 +551,9 @@ def earthquake_df(place):
     today = datetime.datetime.today()
     yesterday = today - timedelta(days=1)
 
-    url = 'https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday)
+    
 
-    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime=2022-05-23&endtime=2022-05-25')
+    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday))
     data = json.loads(json_url.read())
 
     json_dict = data.get('features')
@@ -591,7 +596,7 @@ def earthquake_df(place):
     min_value = column.min()
     
     all = df.loc[df['distance'] == min_value]
-    print(all)
+    
     
     
     
